"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.read_config = void 0;
const fs_1 = require("fs");
const yaml_1 = require("yaml");
const path_1 = require("path");
async function read_config(file) {
    const path = (0, path_1.resolve)(process.cwd(), file);
    const yaml = await fs_1.promises.readFile(path, 'utf8');
    const config = (0, yaml_1.parse)(yaml);
    validate_config(config);
    process_markdown_config(config);
    resolve_paths(path, config);
    return config;
}
exports.read_config = read_config;
function validate_config(config) {
    // todo: validate config
}
function resolve_paths(file_path, config) {
    const base_path = (0, path_1.dirname)(file_path);
    config.input.root = (0, path_1.resolve)(base_path, config.input.root);
    config.output.root = (0, path_1.resolve)(base_path, config.output.root);
    if (config.templates?.layouts) {
        config.templates.layouts = (0, path_1.resolve)(base_path, config.templates.layouts);
    }
    if (config.templates?.partials) {
        config.templates.partials = (0, path_1.resolve)(base_path, config.templates.partials);
    }
}
function process_markdown_config(config) {
    if (config?.markdown?.custom_elements) {
        if (config.markdown.custom_elements.tag_names) {
            const tags = new Set(config.markdown.custom_elements.tag_names);
            config.markdown.custom_elements.tagNameCheck = (tag_name) => tags.has(tag_name);
            delete config.markdown.custom_elements.tag_names;
        }
        if (config.markdown.custom_elements.attribute_names) {
            const attrs = new Set(config.markdown.custom_elements.attribute_names);
            config.markdown.custom_elements.attributeNameCheck = (attr_name) => attrs.has(attr_name);
            delete config.markdown.custom_elements.attribute_names;
        }
    }
}
//# sourceMappingURL=conf.js.map