"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.write_yaml = exports.write_json = exports.write_text = exports.read_yaml = exports.read_json = exports.read_text = exports.mkdirp = exports.load_from_dir = void 0;
const markdown2html_1 = require("@doc-utils/markdown2html");
const fs_1 = require("fs");
const path_1 = require("path");
const yaml_1 = require("yaml");
async function load_from_dir(dir, file) {
    if (!dir) {
        return null;
    }
    const rel_path = (0, path_1.resolve)('/', file);
    const abs_path = (0, path_1.resolve)(dir, '.' + rel_path);
    return await fs_1.promises.readFile(abs_path, 'utf8');
}
exports.load_from_dir = load_from_dir;
function mkdirp(dir, mode = 0o700) {
    return fs_1.promises.mkdir(dir, { mode, recursive: true });
}
exports.mkdirp = mkdirp;
async function read_text(file, check_for_frontmatter = true) {
    const text = await fs_1.promises.readFile(file, 'utf8');
    if (check_for_frontmatter) {
        const { frontmatter, document } = (0, markdown2html_1.process_frontmatter)(text);
        return { frontmatter, text: document };
    }
    return { text, frontmatter: null };
}
exports.read_text = read_text;
async function read_json(file, check_for_frontmatter = true) {
    const json = await fs_1.promises.readFile(file, 'utf8');
    if (check_for_frontmatter) {
        const { frontmatter, document } = (0, markdown2html_1.process_frontmatter)(json);
        const parsed = JSON.parse(document);
        return { frontmatter, json: document, parsed };
    }
    const parsed = JSON.parse(json);
    return { json, parsed, frontmatter: null };
}
exports.read_json = read_json;
async function read_yaml(file, check_for_frontmatter = true) {
    const yaml = await fs_1.promises.readFile(file, 'utf8');
    if (check_for_frontmatter) {
        const { frontmatter, document } = (0, markdown2html_1.process_frontmatter)(yaml);
        const parsed = (0, yaml_1.parse)(document);
        return { frontmatter, yaml: document, parsed };
    }
    const parsed = (0, yaml_1.parse)(yaml);
    return { yaml, parsed, frontmatter: null };
}
exports.read_yaml = read_yaml;
function write_text(file, text) {
    return fs_1.promises.writeFile(file, text, 'utf8');
}
exports.write_text = write_text;
function write_json(file, obj, pretty = true) {
    const json = JSON.stringify(obj, null, pretty ? '  ' : null);
    return fs_1.promises.writeFile(file, json, 'utf8');
}
exports.write_json = write_json;
function write_yaml(file, obj) {
    const yaml = (0, yaml_1.stringify)(obj);
    return fs_1.promises.writeFile(file, yaml, 'utf8');
}
exports.write_yaml = write_yaml;
//# sourceMappingURL=fs.js.map