"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load_partials = exports.load_layout = exports.load_extras = exports.render_template = void 0;
const mustache_1 = require("mustache");
const fs_1 = require("fs");
const path_1 = require("path");
const glob_1 = require("glob");
const fs_2 = require("./fs");
function render_template(template, context, layout, partials = {}, tags) {
    partials['.content'] = template;
    return (0, mustache_1.render)(layout || template, context, partials, tags);
}
exports.render_template = render_template;
async function load_extras() {
    const extras = Object.create(null);
    const extras_dir = (0, path_1.resolve)(__dirname, '../extras');
    const extras_files = [
        'components/color-scheme-toggle-button.js',
        'components/outline-button.js',
        'components/outline-inline.js',
        'prism.css',
        'typography/spacious.css',
        'typography/dense.css',
        'typography/general.css',
        'theme-animation.css',
        'forms-inputs/spacious.css',
        'forms-inputs/dense.css',
        'forms-inputs/general.css',
    ];
    const promises = extras_files.map((file) => (0, fs_2.load_from_dir)(extras_dir, file));
    for (let i = 0; i < extras_files.length; i++) {
        extras[`.extras/${extras_files[i]}`] = await promises[i];
    }
    return extras;
}
exports.load_extras = load_extras;
async function load_layout(conf, file) {
    return (0, fs_2.load_from_dir)(conf.templates?.layouts, file);
}
exports.load_layout = load_layout;
async function load_partials(conf) {
    const path = conf.templates?.partials;
    if (!path) {
        return {};
    }
    const partials = {};
    const partial_files = await (0, glob_1.glob)(path + '/**/*', {
        cwd: path,
        absolute: false,
    });
    for (const file of partial_files) {
        const abs_file = (0, path_1.resolve)(path, file);
        partials[file] = await fs_1.promises.readFile(abs_file, 'utf8');
    }
    return partials;
}
exports.load_partials = load_partials;
//# sourceMappingURL=template.js.map