"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.render_theme_css_properties = exports.load_local_theme = exports.load_theme = exports.load_themes = void 0;
const glob_1 = require("glob");
const fs_1 = require("./fs");
const color_themes_1 = require("@doc-utils/color-themes");
async function load_themes(conf) {
    const themes = {};
    for (const theme of color_themes_1.themes) {
        themes[theme] = (0, color_themes_1.load_theme)(theme);
    }
    if (conf.templates?.themes) {
        const local_themes = await (0, glob_1.glob)(conf.templates.themes + '/**/theme.json');
        for (const theme_path of local_themes) {
            const segments = theme_path.split('/');
            const theme = segments[segments.length - 2];
            themes[theme] = await load_local_theme(conf, theme);
        }
    }
    return themes;
}
exports.load_themes = load_themes;
async function load_theme(conf, name) {
    if (name.includes('/')) {
        return null;
    }
    const local_theme = await load_local_theme(conf, name);
    if (local_theme) {
        return local_theme;
    }
    return (0, color_themes_1.load_theme)(name);
}
exports.load_theme = load_theme;
async function load_local_theme(conf, name) {
    let json;
    try {
        json = await (0, fs_1.load_from_dir)(conf.templates?.themes, `./${name}/theme.json`);
    }
    catch (error) {
        return null;
    }
    const theme = JSON.parse(json);
    (0, color_themes_1.validate_theme)(theme);
    return theme;
}
exports.load_local_theme = load_local_theme;
function render_theme_css_properties(theme) {
    return Object
        .entries(theme.colors)
        .map(([name, color]) => {
        return `--theme-${name.replace(/_/g, '-')}: ${color};`;
    })
        .join('\n') + '\n';
}
exports.render_theme_css_properties = render_theme_css_properties;
//# sourceMappingURL=themes.js.map